Parser

Struct Parser 

pub struct Parser<'a> { /* private fields */ }
A BTOR2 parser.

Implementations

Source

impl<'a> Parser<'a>

pub fn new(reader: LineReader<'a>, config: Config) -> Result<Self, ParseError>

Creates a parser reading from a LineReader.

pub fn from_buf_reader( buf_reader: BufReader<impl Read + 'a>, config: Config, ) -> Result<Self, ParseError>

Creates a parser reading from a BufReader.

pub fn from_read( read: impl Read + 'a, config: Config, ) -> Result<Self, ParseError>

Creates a parser reading from a Read instance.

If the Read instance is a BufReader, it is better to use from_buf_reader to avoid unnecessary double buffering of the data.

Examples found in repository?
examples/roundtrip.rs (line 17)
13fn main_err() -> Result<(), ParseError> {
14    let stdin = std::io::stdin();
15    let stdout = std::io::stdout();
16
17    let mut parser = Parser::from_read(stdin, Default::default())?;
18    let mut target = DeferredWriter::from_write(stdout);
19
20    while let Some(line) = parser.next_line()? {
21        line.write_into(&mut target);
22    }
23    target.flush()?;
24
25    Ok(())
26}
pub fn from_boxed_dyn_read( read: Box<dyn Read + 'a>, config: Config, ) -> Result<Self, ParseError>

Creates a parser reading from a boxed Read instance.

If the Read instance is a BufReader, it is better to use from_buf_reader to avoid unnecessary double buffering of the data.

pub fn next_line(&mut self) -> Result<Option<Line<'_>>, ParseError>

Parses the next line of the BTOR2 file.

Returns Ok(None) when reaching the end of the file.

Examples found in repository?
examples/roundtrip.rs (line 20)
13fn main_err() -> Result<(), ParseError> {
14    let stdin = std::io::stdin();
15    let stdout = std::io::stdout();
16
17    let mut parser = Parser::from_read(stdin, Default::default())?;
18    let mut target = DeferredWriter::from_write(stdout);
19
20    while let Some(line) = parser.next_line()? {
21        line.write_into(&mut target);
22    }
23    target.flush()?;
24
25    Ok(())
26}